@@ -20,7 +20,9 @@ impl<T> Request<T> {
 
 #[derive(Debug, Deserialize)]
 pub struct Response<T> {
+	#[serde(rename = "result")]
 	_result: String,
+	#[serde(rename = "tag")]
 	_tag: u8,
 	pub arguments: T
 }
