@@ -10,6 +10,8 @@ pub enum Error {
 	HTTPUnknown,
 	#[error("JSON error:  {0}")]
 	JSON(#[from] serde_json::Error),
+	#[error("I/O error:  {0}")]
+	IO(#[from] std::io::Error),
 	#[error("got more than one 'torrents' entry in a get files response")]
 	WeirdGetFilesResponse,
 }
